Calculate the residuals of the sample selection model using robust fit.
# S3 method for heckit5rob
residuals(object, ...)object of class "heckitrob" or object of class "heckit5rob"
currently not used
The numeric vector(s) of the residuals.
In case of truncated selection model one vector of residuals is returned. In case of switching regression model a list containing two vectors corresponding to two regimes is returned.