residuals.heckitrob: Residuals of Robust Sample Selection Model Fit
Description
Calculate the residuals of the sample selection model using robust fit.
Usage
# S3 method for heckitrob
residuals(object, ...)
Value
vector(s) of residuals.
Details
In case of truncated selection model one vector of residuals is returned. In case of switching regression model a list containing two vectors corresponding to two regimes is returned.