Extract the variance covariance matrix of the robust sample selection model fit
# S3 method for heckitrob
vcov(object, ...)object of class "heckitrob" or object of class "heckit5rob"
currently not used
Variance covariance matrix of the second stage. Variance covariance matrix of the selection stage can be extracted using the vcov function for the probit estimator, e.g. vcov(heckitrob.object$stage1).